@@ -8,6 +8,7 @@ class Expression:
         self.__output = []
         self.__is_valid = 1
         self.__tokens = []
+        self.__dice_tosses = []
         self.__token_type = []
         self.__natural_flag = 0
         self.__expression_text = expression
@@ -97,6 +98,12 @@ class Expression:
     def is_1_or_20(self):
         return self.__natural_flag
 
+    def tokens(self):
+        return self.__tokens
+
+    def dice_rolls(self):
+        return self.__dice_tosses
+
     @staticmethod
     def __dice_solver(string, operand_solver):
         faces = 0
@@ -122,6 +129,9 @@ class Expression:
                     ad = int(new_numbers[1])
                     ad_flag = 1
         dice_tosses = operand_solver(1, faces, dice_number)
+        for index in range(dice_number):
+            dice_tuple = (dice_tosses[index], faces)
+            self.__dice_tosses += dice_tuple
         result = 0
         if ad_flag == 0:
             result = sum(dice_tosses)
